// This file is part of InvenioRequests
// Copyright (C) 2022 CERN.
//
// Invenio RDM Records is free software; you can redistribute it and/or modify it
// under the terms of the MIT License; see LICENSE file for more details.

import React from "react";
import { Icon } from "semantic-ui-react";

export const IconSubmitStatus = () => <Icon name="clock outline" />;

export const IconDeleteStatus = () => <Icon name="delete" />;

export const IconAcceptStatus = () => <Icon name="check circle" />;

export const IconDeclineStatus = () => <Icon name="user delete" />;

export const IconCancelStatus = () => <Icon name="cancel" />;

export const IconExpireStatus = () => <Icon name="expire" />;
